==> eam-wshub-proxyclient-11.4-14-sources.jar: net/datastream/schemas/mp_fields/VMRSASSEMBLYID.java <==

package net.datastream.schemas.mp_fields;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlRootElement;
import javax.xml.bind.annotation.XmlType;


/**
 * <p>Classe Java pour anonymous complex type.
 * 
 * <p>Le fragment de schéma suivant indique le contenu attendu figurant dans cette classe.
 * 
 * <pre>
 * &lt;complexType>
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}SYSTEMLEVELCODE"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}ASSEMBLYLEVELID"/>
 *       &lt;/sequence>
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "", propOrder = {
    "systemlevelcode",
    "assemblylevelid"
})
@XmlRootElement(name = "VMRSASSEMBLYID")
public class VMRSASSEMBLYID {

    @XmlElement(name = "SYSTEMLEVELCODE", required = true)
    protected String systemlevelcode;
    @XmlElement(name = "ASSEMBLYLEVELID", required = true)
    protected ASSEMBLYLEVELID_Type assemblylevelid;

    /**
     * Obtient la valeur de la propriété systemlevelcode.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getSYSTEMLEVELCODE() {
        return systemlevelcode;
    }

    /**
     * Définit la valeur de la propriété systemlevelcode.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setSYSTEMLEVELCODE(String value) {
        this.systemlevelcode = value;
    }

    /**
     * Obtient la valeur de la propriété assemblylevelid.
     * 
     * @return
     *     possible object is
     *     {@link ASSEMBLYLEVELID_Type }
     *     
     */
    public ASSEMBLYLEVELID_Type getASSEMBLYLEVELID() {
        return assemblylevelid;
    }

    /**
     * Définit la valeur de la propriété assemblylevelid.
     * 
     * @param value
     *     allowed object is
     *     {@link ASSEMBLYLEVELID_Type }
     *     
     */
    public void setASSEMBLYLEVELID(ASSEMBLYLEVELID_Type value) {
        this.assemblylevelid = value;
    }

}

==> eam-wshub-proxyclient-11.7-4-sources.jar: net/datastream/schemas/mp_fields/VMRSASSEMBLYID.java <==

package net.datastream.schemas.mp_fields;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlRootElement;
import javax.xml.bind.annotation.XmlType;


/**
 * <p>Java class for anonymous complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;complexType>
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}SYSTEMLEVELCODE"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}ASSEMBLYLEVELID"/>
 *       &lt;/sequence>
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "", propOrder = {
    "systemlevelcode",
    "assemblylevelid"
})
@XmlRootElement(name = "VMRSASSEMBLYID")
public class VMRSASSEMBLYID {

    @XmlElement(name = "SYSTEMLEVELCODE", required = true)
    protected String systemlevelcode;
    @XmlElement(name = "ASSEMBLYLEVELID", required = true)
    protected ASSEMBLYLEVELID_Type assemblylevelid;

    /**
     * Gets the value of the systemlevelcode property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getSYSTEMLEVELCODE() {
        return systemlevelcode;
    }

    /**
     * Sets the value of the systemlevelcode property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setSYSTEMLEVELCODE(String value) {
        this.systemlevelcode = value;
    }

    /**
     * Gets the value of the assemblylevelid property.
     * 
     * @return
     *     possible object is
     *     {@link ASSEMBLYLEVELID_Type }
     *     
     */
    public ASSEMBLYLEVELID_Type getASSEMBLYLEVELID() {
        return assemblylevelid;
    }

    /**
     * Sets the value of the assemblylevelid property.
     * 
     * @param value
     *     allowed object is
     *     {@link ASSEMBLYLEVELID_Type }
     *     
     */
    public void setASSEMBLYLEVELID(ASSEMBLYLEVELID_Type value) {
        this.assemblylevelid = value;
    }

}
